<!DOCTYPE html>
<!-- The DOCTYPE declaration defines the output type -->
<!-- In this case, it indicates that the document is written in HTML5. -->

<html>
    <!-- The <html> element is the root element of an HTML page. -->
    <!-- All other elements must be nested within this element. -->
    <!-- It marks the beginning of the HTML document. -->
    <#import "macros_common_general.ftl" as com>

    <!-- Initialize common variables -->
    <@com.initializeMainVariables/>	

    <head>
        <!-- A separate FTL file will need to be created containing the HTML style elements -->
        <#include "example_html_stylesheet.ftl">
        <#-----------------------------------------------------------
        -------------------------------------------------------------
        The stylesheet will add styling to the following elements
        *.cover-page
        *.title
        *.subtitle
        *.table-style1
        --------------------------------------------------------------
        ------------------------------------------------------------->
    </head>

    <body>
        <!-- The body section contains the actual content of the HTML document and displayed in docx. -->
        
        <#-- cover page class *.cover-page -->
        <div class="cover-page">

            <#-- title on cover page -->
            <div class="title">Cover page title</div>

            <#-- subtitle -->
            <div class="subtitle">Cover page sub title</div>     
           
        </div>

        <#-- Heading 1 -->
        <h1 class="Heading1">Heading 1</h1>

                <#-- Use Freemarker to get any IUCLID structure value -->
                Substance name: ${entity.root.name}

            <#-- Heading 1.2 -->     
            <h2 class="Heading2">Heading 1.2</h2>

            <#-- List of IUCLID's composite entity types -->
            <#assign compositeEntityTypes = ["SUBSTANCE", "MIXTURE", "TEMPLATE"]>

            <#-- Returns true if doc is a IUCLID composite entity -->
            <#function isCompositeEntityDocument component>
            <#return compositeEntityTypes?seq_contains(component.documentType)>
            </#function>


                <!-- Start of table -->
                <table class="table-style1">
                
                <!-- The colgroup element is used to group one or more col elements within a table. -->
                <colgroup>
                    <!-- Two columns with equal width -->
                    <col width="33.3%" />
                    <col width="33.3%" />
                    <col width="33.3%" />
                </colgroup>

                <!-- header of the table -->
                <thead>
                    <tr>
                        <th><b>Count number of Documents</b></th>
                        <th><b>Document type</b></th>
                        <th><b>Document name</b></th>
                    </tr>
                </thead>

                <!-- body of table containing table rows and table cells -->
                <tbody>              

                    <!-- *list all the entities of a dossier or dataset -->
                    <#list dossier.components as component>
                        <!-- *check the component is an entitiy with documents -->
                        <#if isCompositeEntityDocument(component)>
                            <#-----------------------------------------------------------
                            -------------------------------------------------------------
                            *list the documents of the component 
                            *from here you can get further information about the document
                            ------------------------------------------------------------>
                            <#list component.documents as document>
                            <tr>
                                <!-- This will start at 1 and add 1 with every new document found -->
                                <td>${document?index + 1}</td>
                                <!-- The document name identifier -->
                                <td>${document?node_name}</td>
                                <!-- The name of the document as displayed in the navigation tree -->
                                <td>${document.name}</td>
                            </tr>
                            </#list>
                        </#if>
                    </#list>
                
                </tbody>
            </table>      


        <#-- Heading 2 -->     
        <h1 class="Heading1">Heading 2</h1>

    </body>

</html>

