<!DOCTYPE html>
<!-- The DOCTYPE declaration defines the output type -->
<!-- In this case, it indicates that the document is written in HTML5. -->

<html>
    <!-- The <html> element is the root element of an HTML page. -->
    <!-- All other elements must be nested within this element. -->
    <!-- It marks the beginning of the HTML document. -->
    <#import "macros_common_general.ftl" as com>

    <!-- Initialize common variables -->
    <@com.initializeMainVariables/>	

    <head>
        <!-- A separate FTL file will need to be created containing the HTML style elements -->
        <#include "example_html_stylesheet.ftl">
        <#-----------------------------------------------------------
        -------------------------------------------------------------
        The stylesheet will add styling to the following elements
        *.cover-page
        *.title
        *.subtitle
        *.table-style1
        --------------------------------------------------------------
        ------------------------------------------------------------->
    </head>

    <body>
        <!-- The body section contains the actual content of the HTML document and displayed in docx. -->
        
        <#-- cover page class *.cover-page -->
        <div class="cover-page">

            <#-- title on cover page -->
            <div class="title">Cover page title</div>

            <#-- subtitle -->
            <div class="subtitle">Cover page sub title</div>     
           
        </div>

        <#-- Heading 1 -->
        <h1 class="Heading1">Heading 1</h1>

                <#-- Use Freemarker to get any IUCLID structure value -->
                Substance name: ${entity.root.name}

            <#-- Heading 1.2 -->     
            <h2 class="Heading2">Heading 1.2</h2>

            <#-- List of IUCLID's composite entity types -->
            <#assign compositeEntityTypes = ["SUBSTANCE", "MIXTURE", "TEMPLATE"]>

            <#-- Returns true if doc is a IUCLID composite entity -->
            <#function isCompositeEntityDocument component>
            <#return compositeEntityTypes?seq_contains(component.documentType)>
            </#function>

            <#-- Returns true if doc is a IUCLID composite entity -->
            <#function isNode child>            
            <#assign nodes = ["picklist_single", "picklist_multi", "text_medium"]>
            <#return nodes?seq_contains(child?node_type)>
            </#function>

                <!-- Start of table -->
                <table class="table-style1">
                
                <!-- The colgroup element is used to group one or more col elements within a table. -->
                <colgroup>
                    <!-- Two columns with equal width -->
                    <col width="5%" />
                    <col width="35%" />
                    <col width="25%" />
                    <col width="35%" />
                </colgroup>

                <!-- header of the table -->
                <thead>
                    <tr>
                        <th><b>Count number of Fields</b></th>
                        <th><b>Field name</b></th>
                        <th><b>Field type</b></th>
                        <th><b>Field value</b></th>
                    </tr>
                </thead>

                <!-- body of table containing table rows and table cells -->
                <tbody>              

                    <!-- list all the composition documents that can be found in Substance -->
                    <#list dossier.components as component>
                        <#if isCompositeEntityDocument(component)>
                            <#list component.documents as document>
                                <#---------------------------------------------------------------
                                when a field is node_type "block" use macro to continue iteration
                                ---------------------------------------------------------------->
                                <@recursivelyIterateDocumentNodes document />                                
                            </#list>
                        </#if>
                    </#list>                
                </tbody>
            </table>      


        <#-- Heading 2 -->     
        <h1 class="Heading1">Heading 2</h1>

<#macro recursivelyIterateDocumentNodes document>
<#local node = []/>
 <#list document?children as child>
        <#local isMatchingNode = isNode(child)>
        <#if isMatchingNode && child?has_content>
        <@iuclid.label for=child var="fieldLabel"/>
            <tr>
                <!-- This will start at 1 and add 1 with every new field -->
                <td>${child?index + 1}</td>
                <!-- The field label -->
                <td>${fieldLabel}</td>
                <!-- The field type -->
                <td>${child?node_type}</td>
                <#-----------------------------------------------------
                The field value retrieved using *macros_common_general
                and *@com.value which checks the node_type and returns
                the relevant value
                ------------------------------------------------------>
                <td><@com.value child/></td>
            </tr>
            <#---------------------------------------
            If the field node is block reiterate
            ---------------------------------------->
            <#elseif child?node_type=="block">
            <@recursivelyIterateDocumentNodes child/>
        </#if>
    </#list>

</#macro>


    </body>

</html>

